#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

# coding: utf-8

"""
    Apache Iceberg REST Catalog API

    Defines the specification for the first version of the REST Catalog API. Implementations should ideally support both Iceberg table specs v1 and v2, with priority given to v2.

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from polaris.catalog.models.delete_file import DeleteFile
from polaris.catalog.models.file_scan_task import FileScanTask
from polaris.catalog.models.plan_status import PlanStatus
from typing import Optional, Set
from typing_extensions import Self

class CompletedPlanningResult(BaseModel):
    """
    Completed server-side planning result
    """ # noqa: E501
    delete_files: Optional[List[DeleteFile]] = Field(default=None, description="Delete files referenced by file scan tasks", alias="delete-files")
    file_scan_tasks: Optional[List[FileScanTask]] = Field(default=None, alias="file-scan-tasks")
    plan_tasks: Optional[List[StrictStr]] = Field(default=None, alias="plan-tasks")
    status: PlanStatus
    __properties: ClassVar[List[str]] = ["delete-files", "file-scan-tasks", "plan-tasks", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CompletedPlanningResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in delete_files (list)
        _items = []
        if self.delete_files:
            for _item_delete_files in self.delete_files:
                if _item_delete_files:
                    _items.append(_item_delete_files.to_dict())
            _dict['delete-files'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in file_scan_tasks (list)
        _items = []
        if self.file_scan_tasks:
            for _item_file_scan_tasks in self.file_scan_tasks:
                if _item_file_scan_tasks:
                    _items.append(_item_file_scan_tasks.to_dict())
            _dict['file-scan-tasks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CompletedPlanningResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "delete-files": [DeleteFile.from_dict(_item) for _item in obj["delete-files"]] if obj.get("delete-files") is not None else None,
            "file-scan-tasks": [FileScanTask.from_dict(_item) for _item in obj["file-scan-tasks"]] if obj.get("file-scan-tasks") is not None else None,
            "plan-tasks": obj.get("plan-tasks"),
            "status": obj.get("status")
        })
        return _obj


