#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#

# coding: utf-8

"""
    Apache Iceberg REST Catalog API

    Defines the specification for the first version of the REST Catalog API. Implementations should ideally support both Iceberg table specs v1 and v2, with priority given to v2.

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from polaris.catalog.models.data_file import DataFile
from polaris.catalog.models.expression import Expression
from typing import Optional, Set
from typing_extensions import Self

class FileScanTask(BaseModel):
    """
    FileScanTask
    """ # noqa: E501
    data_file: DataFile = Field(alias="data-file")
    delete_file_references: Optional[List[StrictInt]] = Field(default=None, description="A list of indices in the delete files array (0-based)", alias="delete-file-references")
    residual_filter: Optional[Expression] = Field(default=None, description="An optional filter to be applied to rows in this file scan task. If the residual is not present, the client must produce the residual or use the original filter.", alias="residual-filter")
    __properties: ClassVar[List[str]] = ["data-file", "delete-file-references", "residual-filter"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FileScanTask from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data_file
        if self.data_file:
            _dict['data-file'] = self.data_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of residual_filter
        if self.residual_filter:
            _dict['residual-filter'] = self.residual_filter.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FileScanTask from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "data-file": DataFile.from_dict(obj["data-file"]) if obj.get("data-file") is not None else None,
            "delete-file-references": obj.get("delete-file-references"),
            "residual-filter": Expression.from_dict(obj["residual-filter"]) if obj.get("residual-filter") is not None else None
        })
        return _obj


